# Set the different path for this activity
# This is sourced by runit.sh
path=$1
activity=money_back_cents
plugindir=$path/../money-activity/.libs
pythonplugindir=$path
resourcedir=$path/../money-activity/resources
section="/math/numeration/money_group"
